mailr4526 - /1.3/test_suite/unit_tests/_prompt/test_minimisation.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on January 09, 2008 - 11:25:
Author: bugman
Date: Wed Jan  9 11:25:14 2008
New Revision: 4526

URL: http://svn.gna.org/viewcvs/relax?rev=4526&view=rev
Log:
Changed all references to 'print_flag' to 'verbosity' in the user function 
arg unit tests.


Modified:
    1.3/test_suite/unit_tests/_prompt/test_minimisation.py

Modified: 1.3/test_suite/unit_tests/_prompt/test_minimisation.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_prompt/test_minimisation.py?rev=4526&r1=4525&r2=4526&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_prompt/test_minimisation.py (original)
+++ 1.3/test_suite/unit_tests/_prompt/test_minimisation.py Wed Jan  9 
11:25:14 2008
@@ -41,8 +41,8 @@
     minimisation_fns = Minimisation(fake_relax.fake_instance())
 
 
-    def test_calc_argfail_print_flag(self):
-        """The print_flag arg test of the calc() user function."""
+    def test_calc_argfail_verbosity(self):
+        """The verbosity arg test of the calc() user function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -51,7 +51,7 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxIntError, self.minimisation_fns.calc, 
print_flag=data[1])
+            self.assertRaises(RelaxIntError, self.minimisation_fns.calc, 
verbosity=data[1])
 
 
     def test_grid_search_argfail_lower(self):
@@ -126,8 +126,8 @@
             self.assertRaises(RelaxBinError, 
self.minimisation_fns.grid_search, constraints=data[1])
 
 
-    def test_grid_search_argfail_print_flag(self):
-        """The print_flag arg test of the grid_search() user function."""
+    def test_grid_search_argfail_verbosity(self):
+        """The verbosity arg test of the grid_search() user function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -136,7 +136,7 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxIntError, 
self.minimisation_fns.grid_search, print_flag=data[1])
+            self.assertRaises(RelaxIntError, 
self.minimisation_fns.grid_search, verbosity=data[1])
 
 
     def test_minimise_argfail_args(self):
@@ -231,8 +231,8 @@
             self.assertRaises(RelaxBinError, self.minimisation_fns.minimise, 
'Newton', scaling=data[1])
 
 
-    def test_minimise_argfail_print_flag(self):
-        """The print_flag arg test of the minimise() user function."""
+    def test_minimise_argfail_verbosity(self):
+        """The verbosity arg test of the minimise() user function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -241,6 +241,6 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxIntError, self.minimisation_fns.minimise, 
'Newton', print_flag=data[1])
-
-
+            self.assertRaises(RelaxIntError, self.minimisation_fns.minimise, 
'Newton', verbosity=data[1])
+
+




Related Messages


Powered by MHonArc, Updated Wed Jan 09 11:40:09 2008